Hamlet Python Executor
=========================

The hamlet python executor is a python client for the hamlet engine and provides two core modules for working with hamlet

- backend - provides api functions that call to the hamlet engine and provide outputs or perform tasks as requested
- command - provides a command line interface over the backend that can be used to perform most tasks available from hamlet

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   config_files
   command_reference
   backend_reference
